==> common_utils-0.0.2-sources.jar: com/hx/lib_common/log/HLog.java <==
package com.hx.lib_common.log;

import android.text.TextUtils;
import android.util.Log;

import org.apache.log4j.Logger;

/**
 * Copyright © 1997 - 2020 Gosuncn. All Rights Reserved
 * Created by huangxi on 2020/5/27 14:33
 * Describe:
 * 日记记录
 */
public class HLog {

    public static void i(String tag, String msg){
        if (HLogConfig.getInstance().getAndroidLogEnable()) {
            Log.i(tag, msg);
        }
        if (HLogConfig.getInstance().getFileLogEnable()){
            getLogger(tag).info(msg);
        }
    }

    public static void d(String tag, String msg){
        if (HLogConfig.getInstance().getAndroidLogEnable()) {
            Log.d(tag, msg);
        }
        if (HLogConfig.getInstance().getFileLogEnable()){
            getLogger(tag).debug(msg);
        }
    }

    public static void w(String tag, String msg){
        if (HLogConfig.getInstance().getAndroidLogEnable()) {
            Log.w(tag, msg);
        }
        if (HLogConfig.getInstance().getFileLogEnable()){
            getLogger(tag).warn(msg);
        }
    }

    public static void e(String tag, String msg){
        if (HLogConfig.getInstance().getAndroidLogEnable()) {
            Log.e(tag, msg);
        }
        if (HLogConfig.getInstance().getFileLogEnable()){
            getLogger(tag).error(msg);
        }
    }

    private static Logger getLogger(String tag) {
        Logger logger;
        if (TextUtils.isEmpty(tag)) {
            logger = Logger.getRootLogger();
        } else {
            logger = Logger.getLogger(tag);
        }
        return logger;
    }
}

==> common_utils-1.0.1-sources.jar: com/hx/lib_common/log/HLog.java <==
package com.hx.lib_common.log;

import android.text.TextUtils;
import android.util.Log;

import org.apache.log4j.Logger;

import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * Copyright © 1997 - 2020 Gosuncn. All Rights Reserved
 * Created by huangxi on 2020/5/27 14:33
 * Describe:
 * 日记记录,需要通过HLogConfig进行初始化
 */
public class HLog {

    public static void i(String tag, String msg){
        if (HLogConfig.getInstance().getAndroidLogEnable()) {
            Log.i(tag, msg);
        }
        if (HLogConfig.getInstance().getFileLogEnable()){
            getLogger(tag).info(msg);
        }
    }

    public static void d(String tag, String msg){
        if (HLogConfig.getInstance().getAndroidLogEnable()) {
            Log.d(tag, msg);
        }
        if (HLogConfig.getInstance().getFileLogEnable()){
            getLogger(tag).debug(msg);
        }
    }

    public static void w(String tag, String msg){
        if (HLogConfig.getInstance().getAndroidLogEnable()) {
            Log.w(tag, msg);
        }
        if (HLogConfig.getInstance().getFileLogEnable()){
            getLogger(tag).warn(msg);
        }
    }

    public static void e(String tag, String msg){
        if (HLogConfig.getInstance().getAndroidLogEnable()) {
            Log.e(tag, msg);
        }
        if (HLogConfig.getInstance().getFileLogEnable()){
            getLogger(tag).error(msg);
        }
    }

    private static String lastLogTime;
    private static Logger getLogger(String tag) {
        Logger logger;
        if (TextUtils.isEmpty(tag)) {
            logger = Logger.getRootLogger();
        } else {
            logger = Logger.getLogger(tag);
        }
        if (HLogConfig.getInstance().isNewFileEveryDay()) {
            String logtime = new SimpleDateFormat("yyyy-MM-dd").format(new Date());
            if (!logtime.equals(lastLogTime)) {
                lastLogTime = logtime;
                HLogConfig.getInstance().reInitConfig();
            }
        }
        return logger;
    }
}
